@@ -1,6 +1,6 @@
 calcRamification <-
 function(figure) {
-  count = 1
+  count = 1; 
   while(figure > 3) {
     figure = figure/3
     count = increment(count)
