@@ -7,9 +7,9 @@ function(daten, decs = 4) {
   sMatrix = createSmallerMatrix(datenMatrix)
   sMatrix = fillMatrix(datenMatrix, sMatrix)
   
-  nrOfZerosSmaller = (length(which(sMatrix == 0)))*9 ## Number of zeros overall in bigger matrix
-  nrOfZerosBigger = as.numeric(length(which(datenMatrix == 0)))
-  nrBoxes = (length(which(sMatrix == 1)))*9
+  nrOfZerosSmaller = sum(sMatrix == 0)*9 ## Number of zeros overall in bigger matrix
+  nrOfZerosBigger = as.numeric(sum(datenMatrix == 0))
+  nrBoxes = sum(sMatrix == 1)*9
   
   ## Calculating the estimator for q
   qEst = max(round((nrOfZerosBigger - nrOfZerosSmaller)/nrBoxes, decs), 0)
@@ -17,9 +17,9 @@ function(daten, decs = 4) {
   sMatrix2 = createSmallerMatrix(sMatrix)
   sMatrix2 = fillMatrix(sMatrix, sMatrix2)
   
-  nrOfZerosSmaller = (length(which(sMatrix2 == 0)))*9 ## Number of zeros overall in bigger matrix
-  nrOfZerosBigger = as.numeric(length(which(sMatrix == 0)))
-  nrBoxes = (length(which(sMatrix2 == 1)))*9
+  nrOfZerosSmaller = sum(sMatrix2 == 0)*9 ## Number of zeros overall in bigger matrix
+  nrOfZerosBigger = as.numeric(sum(sMatrix == 0))
+  nrBoxes = sum(sMatrix2 == 1)*9
   
   ## Calculating the estimator for p
   pEst = max(round((nrOfZerosBigger - nrOfZerosSmaller)/nrBoxes, decs), 0)
